@@ -2,7 +2,7 @@
  * Copyright © 2006 Eric Jonas <jonas@mit.edu>
  * Copyright © 2006 Antoine Tremblay <hexa00@gmail.com>
  * Copyright © 2010 United States Government, Joshua M. Doe <joshua.doe@us.army.mil>
- * Copyright © 2010 Emmanuel Pacaud <emmanuel@gnome.org>
+ * Copyright © 2010-2019 Emmanuel Pacaud <emmanuel@gnome.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -53,9 +53,13 @@ struct _GstAravis {
 
 	gint h_binning;
 	gint v_binning;
-        gboolean packet_resend;
         gint num_buffers;
 
+	/* GigEVision parameters */
+	int packet_size;
+	gboolean auto_packet_size;
+        gboolean packet_resend;
+
 	gint payload;
 
 	guint64 buffer_timeout_us;
