@@ -31,8 +31,6 @@
 
 G_BEGIN_DECLS
 
-typedef void (*ArvFrameCallback)	(ArvBuffer *buffer);
-
 /**
  * ArvBufferStatus:
  * @ARV_BUFFER_STATUS_UNKNOWN: unknown status
@@ -88,26 +86,9 @@ typedef enum {
 } ArvBufferPayloadType;
 
 #define ARV_TYPE_BUFFER             (arv_buffer_get_type ())
-#define ARV_BUFFER(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), ARV_TYPE_BUFFER, ArvBuffer))
-#define ARV_BUFFER_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), ARV_TYPE_BUFFER, ArvBufferClass))
-#define ARV_IS_BUFFER(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ARV_TYPE_BUFFER))
-#define ARV_IS_BUFFER_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), ARV_TYPE_BUFFER))
-#define ARV_BUFFER_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS((obj), ARV_TYPE_BUFFER, ArvBufferClass))
+G_DECLARE_FINAL_TYPE (ArvBuffer, arv_buffer, ARV, BUFFER, GObject)
 
-typedef struct _ArvBufferPrivate ArvBufferPrivate;
-typedef struct _ArvBufferClass ArvBufferClass;
-
-struct _ArvBuffer {
-	GObject	object;
-
-	ArvBufferPrivate *priv;
-};
-
-struct _ArvBufferClass {
-	GObjectClass parent_class;
-};
-
-GType arv_buffer_get_type (void);
+typedef void (*ArvFrameCallback)	(ArvBuffer *buffer);
 
 ArvBuffer *		arv_buffer_new_allocate		(size_t size);
 ArvBuffer *		arv_buffer_new 			(size_t size, void *preallocated);
