@@ -33,21 +33,31 @@
 
 G_BEGIN_DECLS
 
+#define ARV_DEVICE_ERROR arv_device_error_quark()
+
+GQuark 		arv_device_error_quark 		(void);
+
+/**
+ * ArvDeviceError:
+ * @ARV_DEVICE_ERROR_WRONG_FEATURE: Wrong feature type
+ * @ARV_DEVICE_ERROR_FEATURE_NOT_FOUND: Feature node not found
+ * @ARV_DEVICE_ERROR_NOT_CONNECTED: Device is not connected
+ * @ARV_DEVICE_ERROR_PROTOCOL_ERROR: Protocol error
+ * @ARV_DEVICE_ERROR_TRANSFER_ERROR: Transfer error
+ * @ARV_DEVICE_ERROR_TIMEOUT: Tiemout detected
+ */
+
+typedef enum {
+	ARV_DEVICE_ERROR_WRONG_FEATURE,
+	ARV_DEVICE_ERROR_FEATURE_NOT_FOUND,
+	ARV_DEVICE_ERROR_NOT_CONNECTED,
+	ARV_DEVICE_ERROR_PROTOCOL_ERROR,
+	ARV_DEVICE_ERROR_TRANSFER_ERROR,
+	ARV_DEVICE_ERROR_TIMEOUT,
+} ArvDeviceError;
+
 #define ARV_TYPE_DEVICE             (arv_device_get_type ())
-#define ARV_DEVICE(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), ARV_TYPE_DEVICE, ArvDevice))
-#define ARV_DEVICE_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), ARV_TYPE_DEVICE, ArvDeviceClass))
-#define ARV_IS_DEVICE(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ARV_TYPE_DEVICE))
-#define ARV_IS_DEVICE_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), ARV_TYPE_DEVICE))
-#define ARV_DEVICE_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS((obj), ARV_TYPE_DEVICE, ArvDeviceClass))
-
-typedef struct _ArvDevicePrivate ArvDevicePrivate;
-typedef struct _ArvDeviceClass ArvDeviceClass;
-
-struct _ArvDevice {
-	GObject	object;
-
-	ArvDevicePrivate *priv;
-};
+G_DECLARE_DERIVABLE_TYPE (ArvDevice, arv_device, ARV, DEVICE, GObject)
 
 struct _ArvDeviceClass {
 	GObjectClass parent_class;
@@ -66,8 +76,6 @@ struct _ArvDeviceClass {
 	void		(*control_lost)		(ArvDevice *device);
 };
 
-GType arv_device_get_type (void);
-
 ArvStream *	arv_device_create_stream	(ArvDevice *device, ArvStreamCallback callback, void *user_data);
 
 gboolean	arv_device_read_memory 		(ArvDevice *device, guint64 address, guint32 size, void *buffer, GError **error);
@@ -78,6 +86,7 @@ gboolean	arv_device_write_register 	(ArvDevice *device, guint64 address, guint32
 const char * 	arv_device_get_genicam_xml 		(ArvDevice *device, size_t *size);
 ArvGc *		arv_device_get_genicam			(ArvDevice *device);
 
+gboolean 	arv_device_is_feature_available 	(ArvDevice *device, const char *feature, GError **error);
 ArvGcNode *	arv_device_get_feature			(ArvDevice *device, const char *feature);
 
 ArvChunkParser *arv_device_create_chunk_parser		(ArvDevice *device);
