@@ -41,7 +41,7 @@
 #include <arvdebug.h>
 #include <string.h>
 
-struct _ArvGcFeatureNodePrivate {
+typedef struct {
 
 	char *name;
 	ArvGcNameSpace name_space;
@@ -58,7 +58,9 @@ struct _ArvGcFeatureNodePrivate {
 	guint64 change_count;
 
 	char *string_buffer;
-};
+} ArvGcFeatureNodePrivate;
+
+G_DEFINE_ABSTRACT_TYPE_WITH_CODE (ArvGcFeatureNode, arv_gc_feature_node, ARV_TYPE_GC_NODE, G_ADD_PRIVATE (ArvGcFeatureNode))
 
 /* ArvDomNode implementation */
 
@@ -71,35 +73,35 @@ arv_gc_feature_node_can_append_child (ArvDomNode *self, ArvDomNode *child)
 static void
 arv_gc_feature_node_post_new_child (ArvDomNode *self, ArvDomNode *child)
 {
-	ArvGcFeatureNode *node = ARV_GC_FEATURE_NODE (self);
+	ArvGcFeatureNodePrivate *priv = arv_gc_feature_node_get_instance_private (ARV_GC_FEATURE_NODE (self));
 
 	if (ARV_IS_GC_PROPERTY_NODE (child)) {
 		ArvGcPropertyNode *property_node = ARV_GC_PROPERTY_NODE (child);
 
 		switch (arv_gc_property_node_get_node_type (property_node)) {
 			case ARV_GC_PROPERTY_NODE_TYPE_TOOLTIP:
-				node->priv->tooltip = property_node;
+				priv->tooltip = property_node;
 				break;
 			case ARV_GC_PROPERTY_NODE_TYPE_DESCRIPTION:
-				node->priv->description = property_node;
+				priv->description = property_node;
 				break;
 			case ARV_GC_PROPERTY_NODE_TYPE_DISPLAY_NAME:
-				node->priv->display_name = property_node;
+				priv->display_name = property_node;
 				break;
 			case ARV_GC_PROPERTY_NODE_TYPE_P_IS_AVAILABLE:
-				node->priv->is_available = property_node;
+				priv->is_available = property_node;
 				break;
 			case ARV_GC_PROPERTY_NODE_TYPE_P_IS_IMPLEMENTED:
-				node->priv->is_implemented = property_node;
+				priv->is_implemented = property_node;
 				break;
 			case ARV_GC_PROPERTY_NODE_TYPE_P_IS_LOCKED:
-				node->priv->is_locked = property_node;
+				priv->is_locked = property_node;
 				break;
 			case ARV_GC_PROPERTY_NODE_TYPE_ACCESS_MODE:
-				node->priv->access_mode = property_node;
+				priv->access_mode = property_node;
 				break;
 			case ARV_GC_PROPERTY_NODE_TYPE_IMPOSED_ACCESS_MODE:
-				node->priv->imposed_access_mode = property_node;
+				priv->imposed_access_mode = property_node;
 				break;
 			default:
 				break;
@@ -110,35 +112,35 @@ arv_gc_feature_node_post_new_child (ArvDomNode *self, ArvDomNode *child)
 static void
 arv_gc_feature_node_pre_remove_child (ArvDomNode *self, ArvDomNode *child)
 {
-	ArvGcFeatureNode *node = ARV_GC_FEATURE_NODE (self);
+	ArvGcFeatureNodePrivate *priv = arv_gc_feature_node_get_instance_private (ARV_GC_FEATURE_NODE (self));
 
 	if (ARV_IS_GC_PROPERTY_NODE (child)) {
 		ArvGcPropertyNode *property_node = ARV_GC_PROPERTY_NODE (child);
 
 		switch (arv_gc_property_node_get_node_type (property_node)) {
 			case ARV_GC_PROPERTY_NODE_TYPE_TOOLTIP:
-				node->priv->tooltip = NULL;
+				priv->tooltip = NULL;
 				break;
 			case ARV_GC_PROPERTY_NODE_TYPE_DESCRIPTION:
-				node->priv->description = NULL;
+				priv->description = NULL;
 				break;
 			case ARV_GC_PROPERTY_NODE_TYPE_DISPLAY_NAME:
-				node->priv->description = NULL;
+				priv->description = NULL;
 				break;
 			case ARV_GC_PROPERTY_NODE_TYPE_P_IS_AVAILABLE:
-				node->priv->is_available = NULL;
+				priv->is_available = NULL;
 				break;
 			case ARV_GC_PROPERTY_NODE_TYPE_P_IS_IMPLEMENTED:
-				node->priv->is_implemented = NULL;
+				priv->is_implemented = NULL;
 				break;
 			case ARV_GC_PROPERTY_NODE_TYPE_P_IS_LOCKED:
-				node->priv->is_locked = NULL;
+				priv->is_locked = NULL;
 				break;
 			case ARV_GC_PROPERTY_NODE_TYPE_ACCESS_MODE:
-				node->priv->access_mode = NULL;
+				priv->access_mode = NULL;
 				break;
 			case ARV_GC_PROPERTY_NODE_TYPE_IMPOSED_ACCESS_MODE:
-				node->priv->imposed_access_mode =  NULL;
+				priv->imposed_access_mode =  NULL;
 				break;
 			default:
 				break;
@@ -151,23 +153,23 @@ arv_gc_feature_node_pre_remove_child (ArvDomNode *self, ArvDomNode *child)
 static void
 arv_gc_feature_node_set_attribute (ArvDomElement *self, const char *name, const char *value)
 {
-	ArvGcFeatureNode *node = ARV_GC_FEATURE_NODE (self);
+	ArvGcFeatureNodePrivate *priv = arv_gc_feature_node_get_instance_private (ARV_GC_FEATURE_NODE (self));
 
 	if (strcmp (name, "Name") == 0) {
 		ArvGc *genicam;
 
-		g_free (node->priv->name);
-		node->priv->name = g_strdup (value);
+		g_free (priv->name);
+		priv->name = g_strdup (value);
 
 		genicam = arv_gc_node_get_genicam (ARV_GC_NODE (self));
 		/* Kludge around ugly Genicam specification (Really, pre-parsing for EnumEntry Name substitution ?) */
-		if (strcmp (arv_dom_node_get_node_name (ARV_DOM_NODE (node)), "EnumEntry") != 0)
-			arv_gc_register_feature_node (genicam, node);
+		if (strcmp (arv_dom_node_get_node_name (ARV_DOM_NODE (self)), "EnumEntry") != 0)
+			arv_gc_register_feature_node (genicam, ARV_GC_FEATURE_NODE (self));
 	} else if (strcmp (name, "NameSpace") == 0) {
 		if (g_strcmp0 (value, "Standard") == 0)
-			node->priv->name_space = ARV_GC_NAME_SPACE_STANDARD;
+			priv->name_space = ARV_GC_NAME_SPACE_STANDARD;
 		else
-			node->priv->name_space = ARV_GC_NAME_SPACE_CUSTOM;
+			priv->name_space = ARV_GC_NAME_SPACE_CUSTOM;
 	} else
 		arv_debug_dom ("[GcFeature::set_attribute] Unknown attribute '%s'", name);
 }
@@ -175,12 +177,12 @@ arv_gc_feature_node_set_attribute (ArvDomElement *self, const char *name, const
 static const char *
 arv_gc_feature_node_get_attribute (ArvDomElement *self, const char *name)
 {
-	ArvGcFeatureNode *node = ARV_GC_FEATURE_NODE (self);
+	ArvGcFeatureNodePrivate *priv = arv_gc_feature_node_get_instance_private (ARV_GC_FEATURE_NODE (self));
 
 	if (strcmp (name, "Name") == 0)
-		return node->priv->name;
+		return priv->name;
 	else if (strcmp (name, "NameSpace") == 0)
-		switch (node->priv->name_space) {
+		switch (priv->name_space) {
 			case ARV_GC_NAME_SPACE_STANDARD:
 				return "Standard";
 			default:
@@ -197,24 +199,27 @@ arv_gc_feature_node_get_attribute (ArvDomElement *self, const char *name)
 const char *
 arv_gc_feature_node_get_name (ArvGcFeatureNode *node)
 {
+	ArvGcFeatureNodePrivate *priv = arv_gc_feature_node_get_instance_private (node);
+
 	g_return_val_if_fail (ARV_IS_GC_FEATURE_NODE (node), NULL);
 
-	return node->priv->name;
+	return priv->name;
 }
 
 const char *
 arv_gc_feature_node_get_tooltip (ArvGcFeatureNode *node, GError **error)
 {
+	ArvGcFeatureNodePrivate *priv = arv_gc_feature_node_get_instance_private (node);
 	const char *tooltip;
 	GError *local_error = NULL;
 
 	g_return_val_if_fail (ARV_IS_GC_FEATURE_NODE (node), NULL);
 	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
-	if (node->priv->tooltip == NULL)
+	if (priv->tooltip == NULL)
 		return NULL;
 
-	tooltip = arv_gc_property_node_get_string (node->priv->tooltip, &local_error);
+	tooltip = arv_gc_property_node_get_string (priv->tooltip, &local_error);
 
 	if (local_error != NULL) {
 		g_propagate_error (error, local_error);
@@ -227,16 +232,17 @@ arv_gc_feature_node_get_tooltip (ArvGcFeatureNode *node, GError **error)
 const char *
 arv_gc_feature_node_get_description (ArvGcFeatureNode *node, GError **error)
 {
+	ArvGcFeatureNodePrivate *priv = arv_gc_feature_node_get_instance_private (node);
 	const char *description;
 	GError *local_error = NULL;
 
 	g_return_val_if_fail (ARV_IS_GC_FEATURE_NODE (node), NULL);
 	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
-	if (node->priv->description == NULL)
+	if (priv->description == NULL)
 	       return NULL;
 
-	description = arv_gc_property_node_get_string (node->priv->description, &local_error);
+	description = arv_gc_property_node_get_string (priv->description, &local_error);
 
 	if (local_error != NULL) {
 		g_propagate_error (error, local_error);
@@ -249,16 +255,17 @@ arv_gc_feature_node_get_description (ArvGcFeatureNode *node, GError **error)
 const char *
 arv_gc_feature_node_get_display_name (ArvGcFeatureNode *node, GError **error)
 {
+	ArvGcFeatureNodePrivate *priv = arv_gc_feature_node_get_instance_private (node);
 	const char *display_name;
 	GError *local_error = NULL;
 
 	g_return_val_if_fail (ARV_IS_GC_FEATURE_NODE (node), NULL);
 	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
-	if (node->priv->display_name == NULL)
+	if (priv->display_name == NULL)
 	       return NULL;
 
-	display_name = arv_gc_property_node_get_string (node->priv->display_name, &local_error);
+	display_name = arv_gc_property_node_get_string (priv->display_name, &local_error);
 
 	if (local_error != NULL) {
 		g_propagate_error (error, local_error);
@@ -271,17 +278,18 @@ arv_gc_feature_node_get_display_name (ArvGcFeatureNode *node, GError **error)
 gboolean
 arv_gc_feature_node_is_implemented (ArvGcFeatureNode *gc_feature_node, GError **error)
 {
+	ArvGcFeatureNodePrivate *priv = arv_gc_feature_node_get_instance_private (gc_feature_node);
 	gboolean value;
 	GError *local_error = NULL;
 
 	g_return_val_if_fail (ARV_IS_GC_FEATURE_NODE (gc_feature_node), FALSE);
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-	if (gc_feature_node->priv->is_implemented == NULL)
+	if (priv->is_implemented == NULL)
 		return TRUE;
 
 
-	value = arv_gc_property_node_get_int64 (gc_feature_node->priv->is_implemented, &local_error) != 0;
+	value = arv_gc_property_node_get_int64 (priv->is_implemented, &local_error) != 0;
 
 	if (local_error != NULL) {
 		g_propagate_error (error, local_error);
@@ -294,16 +302,17 @@ arv_gc_feature_node_is_implemented (ArvGcFeatureNode *gc_feature_node, GError **
 gboolean
 arv_gc_feature_node_is_available (ArvGcFeatureNode *gc_feature_node, GError **error)
 {
+	ArvGcFeatureNodePrivate *priv = arv_gc_feature_node_get_instance_private (gc_feature_node);
 	gboolean value;
 	GError *local_error = NULL;
 
 	g_return_val_if_fail (ARV_IS_GC_FEATURE_NODE (gc_feature_node), FALSE);
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-	if (gc_feature_node->priv->is_available == NULL)
+	if (priv->is_available == NULL)
 		return TRUE;
 
-	value = arv_gc_property_node_get_int64 (gc_feature_node->priv->is_available, &local_error) != 0;
+	value = arv_gc_property_node_get_int64 (priv->is_available, &local_error) != 0;
 
 	if (local_error != NULL) {
 		g_propagate_error (error, local_error);
@@ -316,15 +325,16 @@ arv_gc_feature_node_is_available (ArvGcFeatureNode *gc_feature_node, GError **er
 gboolean
 arv_gc_feature_node_is_locked (ArvGcFeatureNode *gc_feature_node, GError **error)
 {
+	ArvGcFeatureNodePrivate *priv = arv_gc_feature_node_get_instance_private (gc_feature_node);
 	gboolean value;
 	GError *local_error = NULL;
 
 	g_return_val_if_fail (ARV_IS_GC_FEATURE_NODE (gc_feature_node), FALSE);
 
-	if (gc_feature_node->priv->is_locked == NULL)
+	if (priv->is_locked == NULL)
 		return FALSE;
 
-	value = arv_gc_property_node_get_int64 (gc_feature_node->priv->is_locked, &local_error) != 0;
+	value = arv_gc_property_node_get_int64 (priv->is_locked, &local_error) != 0;
 
 	if (local_error != NULL) {
 		g_propagate_error (error, local_error);
@@ -393,18 +403,18 @@ arv_gc_feature_node_set_value_from_string (ArvGcFeatureNode *self, const char *s
 const char *
 arv_gc_feature_node_get_value_as_string (ArvGcFeatureNode *self, GError **error)
 {
+	ArvGcFeatureNodePrivate *priv = arv_gc_feature_node_get_instance_private (self);
+
 	g_return_val_if_fail (ARV_IS_GC_FEATURE_NODE (self), NULL);
 
 	if (ARV_IS_GC_INTEGER (self)) {
-		g_free (self->priv->string_buffer);
-		self->priv->string_buffer = g_strdup_printf ("%" G_GINT64_FORMAT, 
-							     arv_gc_integer_get_value (ARV_GC_INTEGER (self), error));
-		return self->priv->string_buffer;
+		g_free (priv->string_buffer);
+		priv->string_buffer = g_strdup_printf ("%" G_GINT64_FORMAT, arv_gc_integer_get_value (ARV_GC_INTEGER (self), error));
+		return priv->string_buffer;
 	} else if (ARV_IS_GC_FLOAT (self)) {
-		g_free (self->priv->string_buffer);
-		self->priv->string_buffer = g_strdup_printf ("%g", 
-							     arv_gc_float_get_value (ARV_GC_FLOAT (self), error));
-		return self->priv->string_buffer;
+		g_free (priv->string_buffer);
+		priv->string_buffer = g_strdup_printf ("%g", arv_gc_float_get_value (ARV_GC_FLOAT (self), error));
+		return priv->string_buffer;
 	} else if (ARV_IS_GC_STRING (self)) {
 		return arv_gc_string_get_value (ARV_GC_STRING (self), error);
 	} else if (ARV_IS_GC_BOOLEAN (self)) {
@@ -420,38 +430,40 @@ arv_gc_feature_node_get_value_as_string (ArvGcFeatureNode *self, GError **error)
 }
 
 void
-arv_gc_feature_node_increment_change_count (ArvGcFeatureNode *gc_feature_node)
+arv_gc_feature_node_increment_change_count (ArvGcFeatureNode *self)
 {
-	g_return_if_fail (ARV_IS_GC_FEATURE_NODE (gc_feature_node));
+	ArvGcFeatureNodePrivate *priv = arv_gc_feature_node_get_instance_private (self);
 
-	gc_feature_node->priv->change_count++;
+	g_return_if_fail (ARV_IS_GC_FEATURE_NODE (self));
+
+	priv->change_count++;
 }
 
 guint64
-arv_gc_feature_node_get_change_count (ArvGcFeatureNode *gc_feature_node)
+arv_gc_feature_node_get_change_count (ArvGcFeatureNode *self)
 {
-	g_return_val_if_fail (ARV_IS_GC_FEATURE_NODE (gc_feature_node), 0);
+	ArvGcFeatureNodePrivate *priv = arv_gc_feature_node_get_instance_private (self);
 
-	return gc_feature_node->priv->change_count;
+	g_return_val_if_fail (ARV_IS_GC_FEATURE_NODE (self), 0);
+
+	return priv->change_count;
 }
 
-G_DEFINE_ABSTRACT_TYPE_WITH_CODE (ArvGcFeatureNode, arv_gc_feature_node, ARV_TYPE_GC_NODE, G_ADD_PRIVATE (ArvGcFeatureNode))
-
 static void
-arv_gc_feature_node_init (ArvGcFeatureNode *gc_feature_node)
+arv_gc_feature_node_init (ArvGcFeatureNode *self)
 {
-	gc_feature_node->priv = arv_gc_feature_node_get_instance_private (gc_feature_node);
+	ArvGcFeatureNodePrivate *priv = arv_gc_feature_node_get_instance_private (self);
 
-	gc_feature_node->priv->change_count = 0;
+	priv->change_count = 0;
 }
 
 static void
 arv_gc_feature_node_finalize (GObject *object)
 {
-	ArvGcFeatureNode *node = ARV_GC_FEATURE_NODE(object);
+	ArvGcFeatureNodePrivate *priv = arv_gc_feature_node_get_instance_private (ARV_GC_FEATURE_NODE(object));
 
-	g_clear_pointer (&node->priv->name, g_free);
-	g_clear_pointer (&node->priv->string_buffer, g_free);
+	g_clear_pointer (&priv->name, g_free);
+	g_clear_pointer (&priv->string_buffer, g_free);
 
 	G_OBJECT_CLASS (arv_gc_feature_node_parent_class)->finalize (object);
 }
