@@ -37,18 +37,35 @@
 #include <arvdomtext.h>
 #include <arvmisc.h>
 #include <arvdebug.h>
+#include <arvenumtypes.h>
 #include <string.h>
 
-static GObjectClass *parent_class = NULL;
+enum {
+	ARV_GC_PROPERTY_NODE_PROPERTY_0,
+	ARV_GC_PROPERTY_NODE_PROPERTY_TYPE
+} ArvGcPropertyNodeProperties;
+
+typedef struct {
+	ArvGcNode base;
+
+	ArvGcPropertyNodeType	type;
+
+	char *name;
+
+	gboolean value_data_up_to_date;
+	char *value_data;
+} ArvGcPropertyNodePrivate;
+
+G_DEFINE_TYPE_WITH_CODE (ArvGcPropertyNode, arv_gc_property_node, ARV_TYPE_GC_NODE, G_ADD_PRIVATE (ArvGcPropertyNode))
 
 /* ArvDomNode implementation */
 
 static const char *
 arv_gc_property_node_get_node_name (ArvDomNode *node)
 {
-	ArvGcPropertyNode *property_node = ARV_GC_PROPERTY_NODE (node);
+	ArvGcPropertyNodePrivate *priv = arv_gc_property_node_get_instance_private (ARV_GC_PROPERTY_NODE (node));
 
-	switch (property_node->type) {
+	switch (priv->type) {
 		case ARV_GC_PROPERTY_NODE_TYPE_VALUE:
 			return "Value";
 		case ARV_GC_PROPERTY_NODE_TYPE_ADDRESS:
@@ -159,17 +176,17 @@ _can_append_child (ArvDomNode *self, ArvDomNode *child)
 static void
 _post_new_child (ArvDomNode *parent, ArvDomNode *child)
 {
-	ArvGcPropertyNode *property_node = ARV_GC_PROPERTY_NODE (parent);
+	ArvGcPropertyNodePrivate *priv = arv_gc_property_node_get_instance_private (ARV_GC_PROPERTY_NODE (parent));
 
-	property_node->value_data_up_to_date = FALSE;
+	priv->value_data_up_to_date = FALSE;
 }
 
 static void
 _pre_remove_child (ArvDomNode *parent, ArvDomNode *child)
 {
-	ArvGcPropertyNode *property_node = ARV_GC_PROPERTY_NODE (parent);
+	ArvGcPropertyNodePrivate *priv = arv_gc_property_node_get_instance_private (ARV_GC_PROPERTY_NODE (parent));
 
-	property_node->value_data_up_to_date = FALSE;
+	priv->value_data_up_to_date = FALSE;
 }
 
 /* ArvDomElement implementation */
@@ -177,11 +194,11 @@ _pre_remove_child (ArvDomNode *parent, ArvDomNode *child)
 static void
 arv_gc_property_node_set_attribute (ArvDomElement *self, const char *name, const char *value)
 {
-	ArvGcPropertyNode *gc_property_node = ARV_GC_PROPERTY_NODE (self);
+	ArvGcPropertyNodePrivate *priv = arv_gc_property_node_get_instance_private (ARV_GC_PROPERTY_NODE (self));
 
 	if (strcmp (name, "Name") == 0) {
-		g_free (gc_property_node->name);
-		gc_property_node->name = g_strdup (value);
+		g_free (priv->name);
+		priv->name = g_strdup (value);
 	} else
 		arv_debug_dom ("[GcPropertyNode::set_attribute] Uknown attribute '%s'", name);
 }
@@ -189,10 +206,10 @@ arv_gc_property_node_set_attribute (ArvDomElement *self, const char *name, const
 static const char *
 arv_gc_property_node_get_attribute (ArvDomElement *self, const char *name)
 {
-	ArvGcPropertyNode *gc_property_node = ARV_GC_PROPERTY_NODE (self);
+	ArvGcPropertyNodePrivate *priv = arv_gc_property_node_get_instance_private (ARV_GC_PROPERTY_NODE (self));
 
 	if (strcmp (name, "Name") == 0)
-		return gc_property_node->name;
+		return priv->name;
 
 	arv_debug_dom ("[GcPropertyNode::set_attribute] Uknown attribute '%s'", name);
 
@@ -204,39 +221,45 @@ arv_gc_property_node_get_attribute (ArvDomElement *self, const char *name)
 static const char *
 _get_value_data (ArvGcPropertyNode *property_node)
 {
+	ArvGcPropertyNodePrivate *priv = arv_gc_property_node_get_instance_private (property_node);
 	ArvDomNode *dom_node = ARV_DOM_NODE (property_node);
 
-	if (!property_node->value_data_up_to_date) {
+	if (!priv->value_data_up_to_date) {
 		ArvDomNode *iter;
 		GString *string = g_string_new (NULL);
 
-		for (iter = dom_node->first_child; iter != NULL; iter = iter->next_sibling)
+		for (iter = arv_dom_node_get_first_child (dom_node);
+		     iter != NULL;
+		     iter = arv_dom_node_get_next_sibling (iter))
 			g_string_append (string, arv_dom_character_data_get_data (ARV_DOM_CHARACTER_DATA (iter)));
-		g_free (property_node->value_data);
-		property_node->value_data = string->str;
+		g_free (priv->value_data);
+		priv->value_data = string->str;
 		g_string_free (string, FALSE);
-		property_node->value_data_up_to_date = TRUE;
+		priv->value_data_up_to_date = TRUE;
 	}
 
-	return property_node->value_data;
+	return priv->value_data;
 }
 
 static void
 _set_value_data (ArvGcPropertyNode *property_node, const char *data)
 {
+	ArvGcPropertyNodePrivate *priv = arv_gc_property_node_get_instance_private (property_node);
 	ArvDomNode *dom_node = ARV_DOM_NODE (property_node);
 
-	if (dom_node->first_child != NULL) {
+	if (arv_dom_node_get_first_child (dom_node) != NULL) {
 		ArvDomNode *iter;
 
-		arv_dom_character_data_set_data (ARV_DOM_CHARACTER_DATA (dom_node->first_child), data);
-		for (iter = dom_node->first_child->next_sibling; iter != NULL; iter = iter->next_sibling)
+		arv_dom_character_data_set_data (ARV_DOM_CHARACTER_DATA (arv_dom_node_get_first_child (dom_node)), data);
+		for (iter = arv_dom_node_get_next_sibling (arv_dom_node_get_first_child (dom_node));
+		     iter != NULL;
+		     iter = arv_dom_node_get_next_sibling (iter))
 			arv_dom_character_data_set_data (ARV_DOM_CHARACTER_DATA (iter), "");
 	}
 
-	g_free (property_node->value_data);
-	property_node->value_data = g_strdup (data);
-	property_node->value_data_up_to_date = TRUE;
+	g_free (priv->value_data);
+	priv->value_data = g_strdup (data);
+	priv->value_data_up_to_date = TRUE;
 }
 
 static ArvDomNode *
@@ -246,7 +269,7 @@ _get_pvalue_node (ArvGcPropertyNode *property_node)
 	const char *node_name;
 	ArvGc *genicam;
 
-	if (property_node->type < ARV_GC_PROPERTY_NODE_TYPE_P_UNKNONW)
+	if (arv_gc_property_node_get_node_type (property_node) < ARV_GC_PROPERTY_NODE_TYPE_P_UNKNONW)
 		return NULL;
 
 	node_name = _get_value_data (property_node);
@@ -268,9 +291,11 @@ _get_pvalue_node (ArvGcPropertyNode *property_node)
 const char *
 arv_gc_property_node_get_name (ArvGcPropertyNode *node)
 {
+	ArvGcPropertyNodePrivate *priv = arv_gc_property_node_get_instance_private (node);
+
 	g_return_val_if_fail (ARV_IS_GC_PROPERTY_NODE (node), NULL);
 
-	return node->name;
+	return priv->name;
 }
 
 const char *
@@ -452,9 +477,11 @@ arv_gc_property_node_set_double (ArvGcPropertyNode *node, double v_double, GErro
 ArvGcPropertyNodeType
 arv_gc_property_node_get_node_type (ArvGcPropertyNode *node)
 {
+	ArvGcPropertyNodePrivate *priv = arv_gc_property_node_get_instance_private (node);
+
 	g_return_val_if_fail (ARV_IS_GC_PROPERTY_NODE (node), ARV_GC_PROPERTY_NODE_TYPE_UNKNOWN);
 
-	return node->type;
+	return priv->type;
 }
 
 /**
@@ -471,7 +498,7 @@ arv_gc_property_node_get_linked_node (ArvGcPropertyNode *node)
 
 	g_return_val_if_fail (ARV_IS_GC_PROPERTY_NODE (node), NULL);
 
-	if (node->type <= ARV_GC_PROPERTY_NODE_TYPE_P_UNKNONW)
+	if (arv_gc_property_node_get_node_type (node) <= ARV_GC_PROPERTY_NODE_TYPE_P_UNKNONW)
 		return NULL;
 
 	genicam = arv_gc_node_get_genicam (ARV_GC_NODE (node));
@@ -481,12 +508,7 @@ arv_gc_property_node_get_linked_node (ArvGcPropertyNode *node)
 static ArvGcNode *
 arv_gc_property_node_new (ArvGcPropertyNodeType type)
 {
-	ArvGcPropertyNode *node;
-
-	node = g_object_new (ARV_TYPE_GC_PROPERTY_NODE, NULL);
-	node->type = type;
-
-	return ARV_GC_NODE (node);
+	return g_object_new (ARV_TYPE_GC_PROPERTY_NODE, "node-type", type, NULL);
 }
 
 ArvGcNode *
@@ -696,14 +718,15 @@ arv_gc_property_node_new_imposed_access_mode (void)
 ArvGcAccessMode
 arv_gc_property_node_get_access_mode (ArvGcPropertyNode *self, ArvGcAccessMode default_value)
 {
+	ArvGcPropertyNodePrivate *priv = arv_gc_property_node_get_instance_private (self);
 	const char *value;
 
 	if (self == NULL)
 		return default_value;
 
 	g_return_val_if_fail (ARV_IS_GC_PROPERTY_NODE (self), default_value);
-	g_return_val_if_fail (self->type == ARV_GC_PROPERTY_NODE_TYPE_ACCESS_MODE ||
-			      self->type == ARV_GC_PROPERTY_NODE_TYPE_IMPOSED_ACCESS_MODE, default_value);
+	g_return_val_if_fail (priv->type == ARV_GC_PROPERTY_NODE_TYPE_ACCESS_MODE ||
+			      priv->type == ARV_GC_PROPERTY_NODE_TYPE_IMPOSED_ACCESS_MODE, default_value);
 
 	value = _get_value_data (self);
 
@@ -724,13 +747,14 @@ arv_gc_property_node_new_cachable (void)
 ArvGcCachable
 arv_gc_property_node_get_cachable (ArvGcPropertyNode *self, ArvGcCachable default_value)
 {
+	ArvGcPropertyNodePrivate *priv = arv_gc_property_node_get_instance_private (self);
 	const char *value;
 
 	if (self == NULL)
 		return default_value;
 
 	g_return_val_if_fail (ARV_IS_GC_PROPERTY_NODE (self), default_value);
-	g_return_val_if_fail (self->type == ARV_GC_PROPERTY_NODE_TYPE_CACHABLE, default_value);
+	g_return_val_if_fail (priv->type == ARV_GC_PROPERTY_NODE_TYPE_CACHABLE, default_value);
 
 	value = _get_value_data (self);
 
@@ -757,11 +781,13 @@ arv_gc_property_node_new_endianess (void)
 guint
 arv_gc_property_node_get_endianess (ArvGcPropertyNode *self, guint default_value)
 {
+	ArvGcPropertyNodePrivate *priv = arv_gc_property_node_get_instance_private (self);
+
 	if (self == NULL)
 		return default_value;
 
 	g_return_val_if_fail (ARV_IS_GC_PROPERTY_NODE (self), default_value);
-	g_return_val_if_fail (self->type == ARV_GC_PROPERTY_NODE_TYPE_ENDIANESS, default_value);
+	g_return_val_if_fail (priv->type == ARV_GC_PROPERTY_NODE_TYPE_ENDIANESS, default_value);
 
 	if (g_strcmp0 (_get_value_data (self), "BigEndian") == 0)
 		return G_BIG_ENDIAN;
@@ -778,11 +804,13 @@ arv_gc_property_node_new_sign (void)
 ArvGcSignedness
 arv_gc_property_node_get_sign (ArvGcPropertyNode *self, ArvGcSignedness default_value)
 {
+	ArvGcPropertyNodePrivate *priv = arv_gc_property_node_get_instance_private (self);
+
 	if (self == NULL)
 		return default_value;
 
 	g_return_val_if_fail (ARV_IS_GC_PROPERTY_NODE (self), default_value);
-	g_return_val_if_fail (self->type == ARV_GC_PROPERTY_NODE_TYPE_SIGN, default_value);
+	g_return_val_if_fail (priv->type == ARV_GC_PROPERTY_NODE_TYPE_SIGN, default_value);
 
 	if (g_strcmp0 (_get_value_data (self), "Unsigned") == 0)
 		return ARV_GC_SIGNEDNESS_UNSIGNED;
@@ -799,12 +827,14 @@ arv_gc_property_node_new_lsb (void)
 guint
 arv_gc_property_node_get_lsb (ArvGcPropertyNode *self, guint default_value)
 {
+	ArvGcPropertyNodePrivate *priv = arv_gc_property_node_get_instance_private (self);
+
 	if (self == NULL)
 		return default_value;
 
 	g_return_val_if_fail (ARV_IS_GC_PROPERTY_NODE (self), default_value);
-	g_return_val_if_fail (self->type == ARV_GC_PROPERTY_NODE_TYPE_LSB ||
-			      self->type == ARV_GC_PROPERTY_NODE_TYPE_BIT, default_value);
+	g_return_val_if_fail (priv->type == ARV_GC_PROPERTY_NODE_TYPE_LSB ||
+			      priv->type == ARV_GC_PROPERTY_NODE_TYPE_BIT, default_value);
 
 	return g_ascii_strtoll (_get_value_data (self), NULL, 10);
 }
@@ -818,12 +848,14 @@ arv_gc_property_node_new_msb (void)
 guint
 arv_gc_property_node_get_msb (ArvGcPropertyNode *self, guint default_value)
 {
+	ArvGcPropertyNodePrivate *priv = arv_gc_property_node_get_instance_private (self);
+
 	if (self == NULL)
 		return default_value;
 
 	g_return_val_if_fail (ARV_IS_GC_PROPERTY_NODE (self), default_value);
-	g_return_val_if_fail (self->type == ARV_GC_PROPERTY_NODE_TYPE_MSB ||
-			      self->type == ARV_GC_PROPERTY_NODE_TYPE_BIT, default_value);
+	g_return_val_if_fail (priv->type == ARV_GC_PROPERTY_NODE_TYPE_MSB ||
+			      priv->type == ARV_GC_PROPERTY_NODE_TYPE_BIT, default_value);
 
 	return g_ascii_strtoll (_get_value_data (self), NULL, 10);
 }
@@ -871,22 +903,54 @@ arv_gc_property_node_new_p_value_default (void)
 }
 
 static void
-arv_gc_property_node_init (ArvGcPropertyNode *gc_property_node)
+_set_property (GObject * object, guint prop_id,
+	       const GValue * value, GParamSpec * pspec)
 {
-	gc_property_node->type = 0;
-	gc_property_node->value_data = NULL;
-	gc_property_node->value_data_up_to_date = FALSE;
+	ArvGcPropertyNodePrivate *priv = arv_gc_property_node_get_instance_private (ARV_GC_PROPERTY_NODE (object));
+
+	switch (prop_id) {
+		case ARV_GC_PROPERTY_NODE_PROPERTY_TYPE:
+			priv->type = g_value_get_enum (value);
+			break;
+		default:
+			g_assert_not_reached ();
+	}
+}
+
+static void
+_get_property (GObject * object, guint prop_id,
+	       GValue * value, GParamSpec * pspec)
+{
+	ArvGcPropertyNodePrivate *priv = arv_gc_property_node_get_instance_private (ARV_GC_PROPERTY_NODE (object));
+
+	switch (prop_id) {
+		case ARV_GC_PROPERTY_NODE_PROPERTY_TYPE:
+			g_value_set_enum (value, priv->type);
+			break;
+		default:
+			g_assert_not_reached ();
+	}
+}
+
+static void
+arv_gc_property_node_init (ArvGcPropertyNode *self)
+{
+	ArvGcPropertyNodePrivate *priv = arv_gc_property_node_get_instance_private (self);
+
+	priv->type = ARV_GC_PROPERTY_NODE_TYPE_UNKNOWN;
+	priv->value_data = NULL;
+	priv->value_data_up_to_date = FALSE;
 }
 
 static void
 arv_gc_property_node_finalize (GObject *object)
 {
-	ArvGcPropertyNode *property_node = ARV_GC_PROPERTY_NODE (object);
+	ArvGcPropertyNodePrivate *priv = arv_gc_property_node_get_instance_private (ARV_GC_PROPERTY_NODE (object));
 
-	parent_class->finalize (object);
+	G_OBJECT_CLASS (arv_gc_property_node_parent_class)->finalize (object);
 
-	g_free (property_node->value_data);
-	g_free (property_node->name);
+	g_free (priv->value_data);
+	g_free (priv->name);
 }
 
 static void
@@ -896,15 +960,22 @@ arv_gc_property_node_class_init (ArvGcPropertyNodeClass *this_class)
 	ArvDomNodeClass *dom_node_class = ARV_DOM_NODE_CLASS (this_class);
 	ArvDomElementClass *dom_element_class = ARV_DOM_ELEMENT_CLASS (this_class);
 
-	parent_class = g_type_class_peek_parent (this_class);
-
 	object_class->finalize = arv_gc_property_node_finalize;
+	object_class->set_property = _set_property;
+	object_class->get_property = _get_property;
 	dom_node_class->get_node_name = arv_gc_property_node_get_node_name;
 	dom_node_class->can_append_child = _can_append_child;
 	dom_node_class->post_new_child = _post_new_child;
 	dom_node_class->pre_remove_child = _pre_remove_child;
 	dom_element_class->set_attribute = arv_gc_property_node_set_attribute;
 	dom_element_class->get_attribute = arv_gc_property_node_get_attribute;
-}
 
-G_DEFINE_TYPE (ArvGcPropertyNode, arv_gc_property_node, ARV_TYPE_GC_NODE)
+	g_object_class_install_property (
+		object_class, ARV_GC_PROPERTY_NODE_PROPERTY_TYPE,
+		g_param_spec_enum ("node-type", "Node type",
+				   "Actual node type",
+				   ARV_TYPE_GC_PROPERTY_NODE_TYPE,
+				   ARV_GC_PROPERTY_NODE_TYPE_UNKNOWN,
+				   G_PARAM_READWRITE |  G_PARAM_CONSTRUCT_ONLY)
+		);
+}
