@@ -76,11 +76,23 @@ enum {
 
 typedef struct _ArvGvStreamThreadData ArvGvStreamThreadData;
 
-struct _ArvGvStreamPrivate {
+typedef struct {
 	GThread *thread;
 	ArvGvStreamThreadData *thread_data;
+} ArvGvStreamPrivate;
+
+struct _ArvGvStream {
+	ArvStream	stream;
+
+	ArvGvStreamPrivate *priv;
 };
 
+struct _ArvGvStreamClass {
+	ArvStreamClass parent_class;
+};
+
+G_DEFINE_TYPE_WITH_CODE (ArvGvStream, arv_gv_stream, ARV_TYPE_STREAM, G_ADD_PRIVATE (ArvGvStream))
+
 /* Acquisition thread */
 
 typedef struct {
@@ -1068,17 +1080,17 @@ arv_gv_stream_new (ArvGvDevice *gv_device,
 	g_return_val_if_fail (G_IS_INET_ADDRESS (interface_address), NULL);
 	g_return_val_if_fail (G_IS_INET_ADDRESS (device_address), NULL);
 
-	timestamp_tick_frequency = arv_gv_device_get_timestamp_tick_frequency (gv_device);
+	timestamp_tick_frequency = arv_gv_device_get_timestamp_tick_frequency (gv_device, NULL);
 	options = arv_gv_device_get_stream_options (gv_device);
 
-	packet_size = arv_gv_device_get_packet_size (gv_device);
+	packet_size = arv_gv_device_get_packet_size (gv_device, NULL);
 	if (packet_size <= ARV_GVSP_PACKET_PROTOCOL_OVERHEAD) {
-		arv_gv_device_set_packet_size (gv_device, ARV_GV_DEVICE_GVSP_PACKET_SIZE_DEFAULT);
+		arv_gv_device_set_packet_size (gv_device, ARV_GV_DEVICE_GVSP_PACKET_SIZE_DEFAULT, NULL);
 		arv_debug_device ("[GvStream::stream_new] Packet size set to default value (%d)",
 				  ARV_GV_DEVICE_GVSP_PACKET_SIZE_DEFAULT);
 	}
 
-	packet_size = arv_gv_device_get_packet_size (gv_device);
+	packet_size = arv_gv_device_get_packet_size (gv_device, NULL);
 	arv_debug_device ("[GvStream::stream_new] Packet size = %d byte(s)", packet_size);
 
 	g_return_val_if_fail (packet_size > ARV_GVSP_PACKET_PROTOCOL_OVERHEAD, NULL);
@@ -1162,6 +1174,13 @@ arv_gv_stream_new (ArvGvDevice *gv_device,
 
 /* ArvStream implementation */
 
+/**
+ * arv_gv_stream_get_statistics:
+ * @gv_stream: a #ArvGvStream
+ * @n_resent_packets: (out)
+ * @n_missing_packets: (out)
+ */
+
 void
 arv_gv_stream_get_statistics (ArvGvStream *gv_stream,
 			      guint64 *n_resent_packets,
@@ -1264,8 +1283,6 @@ arv_gv_stream_get_property (GObject * object, guint prop_id,
 	}
 }
 
-G_DEFINE_TYPE_WITH_CODE (ArvGvStream, arv_gv_stream, ARV_TYPE_STREAM, G_ADD_PRIVATE (ArvGvStream))
-
 static void
 arv_gv_stream_init (ArvGvStream *gv_stream)
 {
