@@ -33,19 +33,6 @@
 
 G_BEGIN_DECLS
 
-typedef struct _ArvGvStreamPrivate ArvGvStreamPrivate;
-typedef struct _ArvGvStreamClass ArvGvStreamClass;
-
-struct _ArvGvStream {
-	ArvStream	stream;
-
-	ArvGvStreamPrivate *priv;
-};
-
-struct _ArvGvStreamClass {
-	ArvStreamClass parent_class;
-};
-
 ArvStream * 	arv_gv_stream_new			(ArvGvDevice *gv_device,
 							 GInetAddress *interface_address,
 							 GInetAddress *device_address,
