@@ -33,20 +33,7 @@
 G_BEGIN_DECLS
 
 #define ARV_TYPE_INTERFACE             (arv_interface_get_type ())
-#define ARV_INTERFACE(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), ARV_TYPE_INTERFACE, ArvInterface))
-#define ARV_INTERFACE_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), ARV_TYPE_INTERFACE, ArvInterfaceClass))
-#define ARV_IS_INTERFACE(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ARV_TYPE_INTERFACE))
-#define ARV_IS_INTERFACE_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), ARV_TYPE_INTERFACE))
-#define ARV_INTERFACE_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS((obj), ARV_TYPE_INTERFACE, ArvInterfaceClass))
-
-typedef struct _ArvInterfacePrivate ArvInterfacePrivate;
-typedef struct _ArvInterfaceClass ArvInterfaceClass;
-
-struct _ArvInterface {
-	GObject	object;
-
-	ArvInterfacePrivate *priv;
-};
+G_DECLARE_DERIVABLE_TYPE (ArvInterface, arv_interface, ARV, INTERFACE, GObject)
 
 struct _ArvInterfaceClass {
 	GObjectClass parent_class;
@@ -57,8 +44,6 @@ struct _ArvInterfaceClass {
 	const char *	protocol;
 };
 
-GType arv_interface_get_type (void);
-
 void 			arv_interface_update_device_list 	(ArvInterface *interface);
 unsigned int 		arv_interface_get_n_devices 		(ArvInterface *interface);
 const char * 		arv_interface_get_device_id 		(ArvInterface *interface, unsigned int index);
