@@ -25,25 +25,139 @@
 #include <string.h>
 #include <stdio.h>
 
+static char *arv_option_device_name = NULL;
+static char *arv_option_device_address = NULL;
+static char *arv_option_debug_domains = NULL;
+static char *arv_option_cache_policy = NULL;
+static gboolean arv_option_show_time = FALSE;
+
+static const GOptionEntry arv_option_entries[] =
+{
+	{ "name",		'n', 0, G_OPTION_ARG_STRING,
+		&arv_option_device_name,	NULL, "<device_name>"},
+	{ "address",		'a', 0, G_OPTION_ARG_STRING,
+		&arv_option_device_address,	NULL, "<device_address>"},
+	{ "cache-policy",	'c', 0, G_OPTION_ARG_STRING,
+		&arv_option_cache_policy, 	"Register cache policy", "[disable|enable|debug]" },
+	{ "time",		't', 0, G_OPTION_ARG_NONE,
+		&arv_option_show_time, 		"Show execution time", NULL},
+	{ "debug", 		'd', 0, G_OPTION_ARG_STRING,
+		&arv_option_debug_domains, 	NULL, "<category>[:<level>][,...]" },
+	{ NULL }
+};
+
+static const char
+description_content[] =
+"Command may be one of the following possibilities:\n"
+"\n"
+"  genicam:                          dump the content of the Genicam xml data\n"
+"  features:                         list all features\n"
+"  values:                           list all available feature values\n"
+"  description [<feature>] ...:      show the full feature description\n"
+"  control <feature>[=<value>] ...:  read/write device features\n"
+"\n"
+"If no command is given, this utility will list all the available devices.\n"
+"For the control command, direct access to device registers is provided using a R[address] syntax"
+" in place of a feature name.\n"
+"\n"
+"Examples:\n"
+"\n"
+"arv-tool-" ARAVIS_API_VERSION " control Width=128 Height=128 Gain R[0x10000]=0x10\n"
+"arv-tool-" ARAVIS_API_VERSION " features\n"
+"arv-tool-" ARAVIS_API_VERSION " description Width Height\n"
+"arv-tool-" ARAVIS_API_VERSION " -n Basler-210ab4 genicam\n";
+
+typedef enum {
+	ARV_TOOL_LIST_MODE_FEATURES,
+	ARV_TOOL_LIST_MODE_DESCRIPTIONS,
+	ARV_TOOL_LIST_MODE_VALUES
+} ArvToolListMode;
+
 static void
-arv_tool_list_features (ArvGc *genicam, const char *feature, gboolean show_description, int level)
+arv_tool_list_features (ArvGc *genicam, const char *feature, ArvToolListMode list_mode, int level)
 {
 	ArvGcNode *node;
 
 	node = arv_gc_get_node (genicam, feature);
 	if (ARV_IS_GC_FEATURE_NODE (node) &&
 	    arv_gc_feature_node_is_implemented (ARV_GC_FEATURE_NODE (node), NULL)) {
-		int i;
 
-		for (i = 0; i < level; i++)
-			printf ("    ");
+		if (ARV_IS_GC_CATEGORY (node)) {
+			printf ("%*s%-12s: '%s'\n", 4 * level, "",
+				arv_dom_node_get_node_name (ARV_DOM_NODE (node)),
+				feature);
+		} else {
+			if (arv_gc_feature_node_is_available (ARV_GC_FEATURE_NODE (node), NULL)) {
+				char *value = NULL;
+				GError *error = NULL;
+				gboolean is_selector;
 
-		printf ("%s: '%s'%s\n",
-			arv_dom_node_get_node_name (ARV_DOM_NODE (node)),
-			feature,
-			arv_gc_feature_node_is_available (ARV_GC_FEATURE_NODE (node), NULL) ? "" : " (Not available)");
+				if (list_mode == ARV_TOOL_LIST_MODE_VALUES) {
+					const char *unit;
 
-		if (show_description) {
+					if (ARV_IS_GC_STRING (node) ||
+					    ARV_IS_GC_ENUMERATION (node)) {
+						value = g_strdup_printf ("'%s'", arv_gc_string_get_value (ARV_GC_STRING (node), &error));
+					} else if (ARV_IS_GC_INTEGER (node)) {
+						if (ARV_IS_GC_ENUMERATION (node)) {
+							value = g_strdup_printf ("'%s'",
+										 arv_gc_string_get_value (ARV_GC_STRING (node), &error));
+						} else {
+							unit = arv_gc_integer_get_unit (ARV_GC_INTEGER (node), NULL);
+
+							value = g_strdup_printf ("%" G_GINT64_FORMAT "%s%s",
+										 arv_gc_integer_get_value (ARV_GC_INTEGER (node), &error),
+										 unit != NULL ? " " : "",
+										 unit != NULL ? unit : "");
+						}
+					} else if (ARV_IS_GC_FLOAT (node)) {
+						unit = arv_gc_float_get_unit (ARV_GC_FLOAT (node), NULL);
+
+						value = g_strdup_printf ("%g%s%s",
+									 arv_gc_float_get_value (ARV_GC_FLOAT (node), &error),
+									 unit != NULL ? " " : "",
+									 unit != NULL ? unit : "");
+					} else if (ARV_IS_GC_BOOLEAN (node)) {
+						value = g_strdup_printf ("%s",
+									 arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node), &error) ?
+									 "true" : "false");
+					}
+				}
+
+				is_selector = ARV_IS_GC_SELECTOR (node) && arv_gc_selector_is_selector (ARV_GC_SELECTOR (node));
+
+				if (error != NULL) {
+					g_clear_error (&error);
+				} else {
+					if (value != NULL && value[0] != '\0')
+						printf ("%*s%-12s: '%s' = %s\n", 4 * level, "",
+							arv_dom_node_get_node_name (ARV_DOM_NODE (node)), feature, value);
+					else
+						printf ("%*s%-12s: '%s'\n", 4 * level, "",
+							arv_dom_node_get_node_name (ARV_DOM_NODE (node)), feature);
+
+					if (is_selector) {
+						const GSList *iter;
+
+						for (iter = arv_gc_selector_get_selected_features (ARV_GC_SELECTOR (node));
+						     iter != NULL;
+						     iter = iter->next) {
+							printf (" %*s     * %s\n", 4 * level, " ",
+								arv_gc_feature_node_get_name (iter->data));
+						}
+
+					}
+				}
+
+				g_clear_pointer (&value, g_free);
+			} else {
+				if (list_mode == ARV_TOOL_LIST_MODE_FEATURES)
+					printf ("%*s%-12s: '%s' (Not available)\n", 4 * level, "",
+						arv_dom_node_get_node_name (ARV_DOM_NODE (node)), feature);
+			}
+		}
+
+		if (list_mode == ARV_TOOL_LIST_MODE_DESCRIPTIONS) {
 			const char *description;
 
 			description = arv_gc_feature_node_get_description (ARV_GC_FEATURE_NODE (node), NULL);
@@ -58,18 +172,15 @@ arv_tool_list_features (ArvGc *genicam, const char *feature, gboolean show_descr
 			features = arv_gc_category_get_features (ARV_GC_CATEGORY (node));
 
 			for (iter = features; iter != NULL; iter = iter->next)
-				arv_tool_list_features (genicam, iter->data, show_description, level + 1);
-		} else if (ARV_IS_GC_ENUMERATION (node)) {
+				arv_tool_list_features (genicam, iter->data, list_mode, level + 1);
+		} else if (ARV_IS_GC_ENUMERATION (node) && list_mode == ARV_TOOL_LIST_MODE_FEATURES) {
 			const GSList *childs;
 			const GSList *iter;
 
 			childs = arv_gc_enumeration_get_entries (ARV_GC_ENUMERATION (node));
 			for (iter = childs; iter != NULL; iter = iter->next) {
 				if (arv_gc_feature_node_is_implemented (iter->data, NULL)) {
-					for (i = 0; i < level + 1; i++)
-						printf ("    ");
-
-					printf ("%s: '%s'%s\n",
+					printf ("%*s%-12s: '%s'%s\n", 4 * (level + 1), "",
 						arv_dom_node_get_node_name (iter->data),
 						arv_gc_feature_node_get_name (iter->data),
 						arv_gc_feature_node_is_available (iter->data, NULL) ? "" : " (Not available)");
@@ -80,16 +191,21 @@ arv_tool_list_features (ArvGc *genicam, const char *feature, gboolean show_descr
 }
 
 static void
-arv_tool_execute_command (int argc, char **argv, ArvDevice *device)
+arv_tool_execute_command (int argc, char **argv, ArvDevice *device, ArvRegisterCachePolicy cache_policy)
 {
 	ArvGc *genicam;
 	const char *command = argv[1];
+	gint64 start;
 
 	if (device == NULL || argc < 2)
 		return;
 
+	arv_device_set_register_cache_policy (device, cache_policy);
+
 	genicam = arv_device_get_genicam (device);
 
+	start = g_get_monotonic_time ();
+
 	if (g_strcmp0 (command, "genicam") == 0) {
 		const char *xml;
 		size_t size;
@@ -98,10 +214,12 @@ arv_tool_execute_command (int argc, char **argv, ArvDevice *device)
 		if (xml != NULL)
 			printf ("%*s\n", (int) size, xml);
 	} else if (g_strcmp0 (command, "features") == 0) {
-		arv_tool_list_features (genicam, "Root", FALSE, 0);
+		arv_tool_list_features (genicam, "Root", ARV_TOOL_LIST_MODE_FEATURES, 0);
+	} else if (g_strcmp0 (command, "values") == 0) {
+		arv_tool_list_features (genicam, "Root", ARV_TOOL_LIST_MODE_VALUES, 0);
 	} else if (g_strcmp0 (command, "description") == 0) {
 		if (argc < 3)
-			arv_tool_list_features (genicam, "Root", TRUE, 0);
+			arv_tool_list_features (genicam, "Root", ARV_TOOL_LIST_MODE_DESCRIPTIONS, 0);
 		else {
 			int i;
 
@@ -134,33 +252,35 @@ arv_tool_execute_command (int argc, char **argv, ArvDevice *device)
 					arv_gc_command_execute (ARV_GC_COMMAND (feature), NULL);
 					printf ("%s executed\n", tokens[0]);
 				} else {
-					GType value_type;
 					const char *unit;
+					GError *error = NULL;
 
 					if (tokens[1] != NULL)
 						arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (feature),
-											   tokens[1], NULL);
+											   tokens[1], &error);
 
-					value_type = arv_gc_feature_node_get_value_type (ARV_GC_FEATURE_NODE (feature));
+					if (error == NULL) {
+						if (ARV_IS_GC_STRING (feature) ||
+						    ARV_IS_GC_ENUMERATION (feature)) {
+							const char *value = arv_gc_string_get_value (ARV_GC_STRING (feature), &error);
 
-					switch (value_type) {
-						case G_TYPE_INT64:
-							if (ARV_IS_GC_ENUMERATION (feature)) {
-								printf ("%s = %s\n", tokens[0],
-									arv_gc_string_get_value (ARV_GC_STRING (feature), NULL));
-							} else {
-								gint64 max_int64, min_int64, inc_int64;
+							if (error == NULL)
+								printf ("%s = %s\n", tokens[0], value);
+						} else if (ARV_IS_GC_INTEGER (feature)) {
+							gint64 max_int64, min_int64, inc_int64;
+							gint64 value;
+
+							min_int64 = arv_gc_integer_get_min (ARV_GC_INTEGER (feature), NULL);
+							max_int64 = arv_gc_integer_get_max (ARV_GC_INTEGER (feature), NULL);
+							inc_int64 = arv_gc_integer_get_inc (ARV_GC_INTEGER (feature), NULL);
+							unit = arv_gc_integer_get_unit (ARV_GC_INTEGER (feature), NULL);
+
+							value = arv_gc_integer_get_value (ARV_GC_INTEGER (feature), &error);
+
+							if (error == NULL) {
 								GString *string = g_string_new ("");
 
-								min_int64 = arv_gc_integer_get_min (ARV_GC_INTEGER (feature), NULL);
-								max_int64 = arv_gc_integer_get_max (ARV_GC_INTEGER (feature), NULL);
-								inc_int64 = arv_gc_integer_get_inc (ARV_GC_INTEGER (feature), NULL);
-								unit = arv_gc_integer_get_unit (ARV_GC_INTEGER (feature), NULL);
-
-								g_string_append_printf (string, "%s = %" G_GINT64_FORMAT,
-											tokens[0],
-											arv_gc_integer_get_value (ARV_GC_INTEGER (feature),
-														  NULL));
+								g_string_append_printf (string, "%s = %" G_GINT64_FORMAT, tokens[0], value);
 
 								if (unit != NULL)
 									g_string_append_printf (string, " %s", unit);
@@ -174,21 +294,20 @@ arv_tool_execute_command (int argc, char **argv, ArvDevice *device)
 								printf ("%s\n", string->str);
 								g_string_free (string, TRUE);
 							}
-							break;
-						case G_TYPE_DOUBLE:
-							{
-								double max_double, min_double, inc_double;
-								GString *string = g_string_new ("");
+						} else if (ARV_IS_GC_FLOAT (feature)) {
+							double max_double, min_double, inc_double;
+							GString *string = g_string_new ("");
+							double value;
 
-								min_double = arv_gc_float_get_min (ARV_GC_FLOAT (feature), NULL);
-								max_double = arv_gc_float_get_max (ARV_GC_FLOAT (feature), NULL);
-								inc_double = arv_gc_float_get_inc (ARV_GC_FLOAT (feature), NULL);
-								unit = arv_gc_float_get_unit (ARV_GC_FLOAT (feature), NULL);
+							min_double = arv_gc_float_get_min (ARV_GC_FLOAT (feature), NULL);
+							max_double = arv_gc_float_get_max (ARV_GC_FLOAT (feature), NULL);
+							inc_double = arv_gc_float_get_inc (ARV_GC_FLOAT (feature), NULL);
+							unit = arv_gc_float_get_unit (ARV_GC_FLOAT (feature), NULL);
 
-								g_string_append_printf (string, "%s = %g",
-											tokens[0],
-											arv_gc_float_get_value (ARV_GC_FLOAT (feature),
-														NULL));
+							value = arv_gc_float_get_value (ARV_GC_FLOAT (feature), &error);
+
+							if (error == NULL) {
+								g_string_append_printf (string, "%s = %g", tokens[0], value);
 
 								if (unit != NULL)
 									g_string_append_printf (string, " %s", unit);
@@ -202,21 +321,23 @@ arv_tool_execute_command (int argc, char **argv, ArvDevice *device)
 								printf ("%s\n", string->str);
 								g_string_free (string, TRUE);
 							}
-							break;
-						case G_TYPE_STRING:
-							printf ("%s = %s\n", tokens[0],
-								arv_gc_string_get_value (ARV_GC_STRING (feature), NULL));
-							break;
-						case G_TYPE_BOOLEAN:
-							printf ("%s = %s\n", tokens[0],
-								arv_gc_integer_get_value (ARV_GC_INTEGER (feature), NULL) != 0 ?
-								"true" : "false");
-							break;
-						default:
-							printf ("%s = %s\n", tokens[0],
-								arv_gc_feature_node_get_value_as_string
-								(ARV_GC_FEATURE_NODE (feature),
-								 NULL));
+						} else if (ARV_IS_GC_BOOLEAN (feature)) {
+							gboolean value = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (feature), &error);
+
+							if (error == NULL)
+								printf ("%s = %s\n", tokens[0], value ?  "true" : "false");
+						} else {
+							const char *value =  arv_gc_feature_node_get_value_as_string
+								(ARV_GC_FEATURE_NODE (feature), &error);
+
+							if (error == NULL)
+								printf ("%s = %s\n", tokens[0], value);
+						}
+					}
+
+					if (error != NULL) {
+							printf ("%s read error: %s\n", tokens[0], error->message);
+							g_clear_error (&error);
 					}
 				}
 			} else {
@@ -245,47 +366,16 @@ arv_tool_execute_command (int argc, char **argv, ArvDevice *device)
 	} else {
 		printf ("Unkown command\n");
 	}
+
+	if (arv_option_show_time)
+		printf ("Executed in %g s\n", (g_get_monotonic_time () - start) / 1000000.0);
 }
 
-static char *arv_option_device_name = NULL;
-static char *arv_option_device_address = NULL;
-static char *arv_option_debug_domains = NULL;
-
-static const GOptionEntry arv_option_entries[] =
-{
-	{ "name",		'n', 0, G_OPTION_ARG_STRING,
-		&arv_option_device_name,	NULL, "<device_name>"},
-	{ "address",		'a', 0, G_OPTION_ARG_STRING,
-		&arv_option_device_address,	NULL, "<device_address>"},
-	{ "debug", 		'd', 0, G_OPTION_ARG_STRING,
-		&arv_option_debug_domains, 	NULL, "<category>[:<level>][,...]" },
-	{ NULL }
-};
-
-static const char
-description_content[] =
-"Command may be one of the following possibilities:\n"
-"\n"
-"  genicam:                          dump the content of the Genicam xml data\n"
-"  features:                         list all availale features\n"
-"  description [<feature>] ...:      show the full feature description\n"
-"  control <feature>[=<value>] ...:  read/write device features\n"
-"\n"
-"If no command is given, this utility will list all the available devices.\n"
-"For the control command, direct access to device registers is provided using a R[address] syntax"
-" in place of a feature name.\n"
-"\n"
-"Examples:\n"
-"\n"
-"arv-tool-" ARAVIS_API_VERSION " control Width=128 Height=128 Gain R[0x10000]=0x10\n"
-"arv-tool-" ARAVIS_API_VERSION " features\n"
-"arv-tool-" ARAVIS_API_VERSION " description Width Height\n"
-"arv-tool-" ARAVIS_API_VERSION " -n Basler-210ab4 genicam\n";
-
 int
 main (int argc, char **argv)
 {
 	ArvDevice *device;
+	ArvRegisterCachePolicy cache_policy = ARV_REGISTER_CACHE_POLICY_DEFAULT;
 	const char *device_id;
 	GOptionContext *context;
 	GError *error = NULL;
@@ -306,6 +396,18 @@ main (int argc, char **argv)
 
 	g_option_context_free (context);
 
+	if (arv_option_cache_policy == NULL ||
+	    g_strcmp0 (arv_option_cache_policy, "disable") == 0)
+		cache_policy = ARV_REGISTER_CACHE_POLICY_DISABLE;
+	else if (g_strcmp0 (arv_option_cache_policy, "enable") == 0)
+		cache_policy = ARV_REGISTER_CACHE_POLICY_ENABLE;
+	else if (g_strcmp0 (arv_option_cache_policy, "debug") == 0)
+		cache_policy = ARV_REGISTER_CACHE_POLICY_DEBUG;
+	else {
+		printf ("Invalid cache policy\n");
+		return EXIT_FAILURE;
+	}
+
 	arv_debug_enable (arv_option_debug_domains);
 
 	device_id = arv_option_device_address != NULL ? arv_option_device_address : arv_option_device_name;
@@ -316,7 +418,7 @@ main (int argc, char **argv)
 			if (argc < 2)
 				printf ("%s\n", device_id);
 			else
-				arv_tool_execute_command (argc, argv, device);
+				arv_tool_execute_command (argc, argv, device, cache_policy);
 			g_object_unref (device);
 		} else {
 			fprintf (stderr, "Device '%s' not found\n", device_id);
@@ -332,7 +434,7 @@ main (int argc, char **argv)
 
 				if (ARV_IS_DEVICE (device)) {
 					printf ("%s (%s)\n", device_id, arv_get_device_address (i));
-					arv_tool_execute_command (argc, argv, device);
+					arv_tool_execute_command (argc, argv, device, cache_policy);
 
 					g_object_unref (device);
 				}
