@@ -39,7 +39,7 @@
 
 #define ARV_UV_DEVICE_N_TRIES_MAX	5
 
-struct _ArvUvDevicePrivate {
+typedef struct {
 	char *vendor;
 	char *product;
 	char *serial_nbr;
@@ -62,8 +62,20 @@ struct _ArvUvDevicePrivate {
         guint8 control_endpoint;
         guint8 data_endpoint;
 	gboolean disconnected;
+} ArvUvDevicePrivate;
+
+struct _ArvUvDevice {
+	ArvDevice device;
+
+	ArvUvDevicePrivate *priv;
 };
 
+struct _ArvUvDeviceClass {
+	ArvDeviceClass parent_class;
+};
+
+G_DEFINE_TYPE_WITH_CODE (ArvUvDevice, arv_uv_device, ARV_TYPE_DEVICE, G_ADD_PRIVATE (ArvUvDevice))
+
 /* ArvDevice implementation */
 
 /* ArvUvDevice implementation */
@@ -82,7 +94,7 @@ arv_uv_device_bulk_transfer (ArvUvDevice *uv_device, ArvUvEndpointType endpoint_
 	g_return_val_if_fail (size > 0, FALSE);
 
 	if (uv_device->priv->disconnected) {
-		g_set_error (error, ARV_DEVICE_ERROR, ARV_STATUS_NOT_CONNECTED,
+		g_set_error (error, ARV_DEVICE_ERROR, ARV_DEVICE_ERROR_NOT_CONNECTED,
 			     "Not connected");
 		return FALSE;
 	}
@@ -95,7 +107,7 @@ arv_uv_device_bulk_transfer (ArvUvDevice *uv_device, ArvUvEndpointType endpoint_
 	success = result >= 0;
 
 	if (!success)
-		g_set_error (error, ARV_DEVICE_ERROR, ARV_STATUS_TRANSFER_ERROR,
+		g_set_error (error, ARV_DEVICE_ERROR, ARV_DEVICE_ERROR_TRANSFER_ERROR,
 			     "%s", libusb_error_name (result));
 
 	if (transferred_size != NULL)
@@ -224,7 +236,7 @@ _read_memory (ArvUvDevice *uv_device, guint64 address, guint32 size, void *buffe
 
 	if (!success) {
 		if (error != NULL && *error == NULL)
-			*error = g_error_new (ARV_DEVICE_ERROR, ARV_STATUS_TIMEOUT,
+			*error = g_error_new (ARV_DEVICE_ERROR, ARV_DEVICE_ERROR_TIMEOUT,
 					      "[ArvDevice::read_memory] Timeout");
 	}
 
@@ -356,7 +368,7 @@ _write_memory (ArvUvDevice *uv_device, guint64 address, guint32 size, void *buff
 
 	if (!success) {
 		if (error != NULL && *error == NULL)
-			*error = g_error_new (ARV_DEVICE_ERROR, ARV_STATUS_TIMEOUT,
+			*error = g_error_new (ARV_DEVICE_ERROR, ARV_DEVICE_ERROR_TIMEOUT,
 					      "[ArvDevice::write_memory] Timeout");
 	}
 
@@ -607,6 +619,34 @@ arv_uv_device_get_genicam_xml (ArvDevice *device, size_t *size)
 	return uv_device->priv->genicam_xml;
 }
 
+static void
+reset_endpoint (libusb_device_handle *usb_device, guint8 endpoint, guint8 endpoint_flags)
+{
+	int errcode;
+
+	/* Set endpoint in halt condition */
+	errcode = libusb_control_transfer(usb_device,
+					      LIBUSB_ENDPOINT_OUT | LIBUSB_REQUEST_TYPE_STANDARD | LIBUSB_RECIPIENT_ENDPOINT,
+					      LIBUSB_REQUEST_SET_FEATURE,
+					      0, /* Value: 0=endpoint_halt */
+					      endpoint | endpoint_flags,
+					      0, 0,
+					      1000);
+	if (errcode < 0) {
+		arv_warning_device("Failed to set endpoint %x in halt condition: %s",
+				   endpoint|endpoint_flags, libusb_error_name (errcode));
+		return;
+	}
+
+	/* Clear halt condtion on the endpoint, effectivelly resetting the pipe */
+	errcode = libusb_clear_halt(usb_device, endpoint | endpoint_flags);
+	if (errcode < 0) {
+		arv_warning_device("Failed to clear halt contidion on endpoint: %s",
+				   libusb_error_name (errcode));
+		return;
+	}
+}
+
 static void
 _open_usb_device (ArvUvDevice *uv_device)
 {
@@ -738,11 +778,11 @@ arv_uv_device_new (const char *vendor, const char *product, const char *serial_n
 		return NULL;
 	}
 
+	reset_endpoint (uv_device->priv->usb_device, uv_device->priv->data_endpoint, LIBUSB_ENDPOINT_IN);
+
 	return ARV_DEVICE (uv_device);
 }
 
-G_DEFINE_TYPE_WITH_CODE (ArvUvDevice, arv_uv_device, ARV_TYPE_DEVICE, G_ADD_PRIVATE (ArvUvDevice))
-
 static void
 arv_uv_device_init (ArvUvDevice *uv_device)
 {
