@@ -28,17 +28,12 @@
 #endif
 
 #include <arvtypes.h>
+#include <arvdevice.h>
 
 G_BEGIN_DECLS
 
 #define ARV_TYPE_UV_DEVICE             (arv_uv_device_get_type ())
-#define ARV_UV_DEVICE(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), ARV_TYPE_UV_DEVICE, ArvUvDevice))
-#define ARV_UV_DEVICE_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), ARV_TYPE_UV_DEVICE, ArvUvDeviceClass))
-#define ARV_IS_UV_DEVICE(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ARV_TYPE_UV_DEVICE))
-#define ARV_IS_UV_DEVICE_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), ARV_TYPE_UV_DEVICE))
-#define ARV_UV_DEVICE_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS((obj), ARV_TYPE_UV_DEVICE, ArvUvDeviceClass))
-
-GType arv_uv_device_get_type (void);
+G_DECLARE_FINAL_TYPE (ArvUvDevice, arv_uv_device, ARV, UV_DEVICE, ArvDevice)
 
 ArvDevice * 	arv_uv_device_new 			(const char *vendor, const char *product, const char *serial_nbr);
 
