@@ -33,19 +33,6 @@
 
 G_BEGIN_DECLS
 
-typedef struct _ArvUvStreamPrivate ArvUvStreamPrivate;
-typedef struct _ArvUvStreamClass ArvUvStreamClass;
-
-struct _ArvUvStream {
-	ArvStream	stream;
-
-	ArvUvStreamPrivate *priv;
-};
-
-struct _ArvUvStreamClass {
-	ArvStreamClass parent_class;
-};
-
 ArvStream * 	arv_uv_stream_new	(ArvUvDevice *uv_device, ArvStreamCallback callback, void *user_data);
 
 G_END_DECLS
