@@ -55,9 +55,6 @@ int main(int argc, char *argv[])
     void (*old_sigint_handler)(int);
     int i, payload;
 
-    arv_g_thread_init (NULL);
-    arv_g_type_init ();
-
     context = g_option_context_new (NULL);
     g_option_context_set_summary (context, "Test of heartbeat robustness while continuously changing a feature.");
     g_option_context_add_main_entries (context, arv_option_entries, NULL);
@@ -85,7 +82,7 @@ int main(int argc, char *argv[])
     if (!ARV_IS_STREAM (stream)) {
 	    printf ("Invalid device\n");
     } else {
-	    payload = arv_camera_get_payload (camera);
+	    payload = arv_camera_get_payload (camera, NULL);
 
 	    if (ARV_IS_GV_STREAM (stream)) {
 		    g_object_set (stream,
@@ -101,11 +98,11 @@ int main(int argc, char *argv[])
 	    for (i = 0; i < 100; i++)
 		    arv_stream_push_buffer(stream, arv_buffer_new(payload, NULL));
 
-	    arv_camera_set_acquisition_mode(camera, ARV_ACQUISITION_MODE_CONTINUOUS);
+	    arv_camera_set_acquisition_mode(camera, ARV_ACQUISITION_MODE_CONTINUOUS, NULL);
 
 	    feature = ARV_GC_FEATURE_NODE (arv_device_get_feature (device, arv_option_feature_name));
 
-	    arv_camera_start_acquisition (camera);
+	    arv_camera_start_acquisition (camera, NULL);
 
 	    old_sigint_handler = signal (SIGINT, set_cancel);
 
@@ -142,7 +139,7 @@ int main(int argc, char *argv[])
 	    printf ("Failures          = %Lu\n", (unsigned long long) n_failures);
 	    printf ("Underruns         = %Lu\n", (unsigned long long) n_underruns);
 
-	    arv_camera_stop_acquisition (camera);
+	    arv_camera_stop_acquisition (camera, NULL);
     }
 
     g_object_unref (camera);
