@@ -286,12 +286,12 @@ fake_stream_test (void)
 
 	arv_fake_camera_set_fill_pattern (fake_camera, fill_pattern_cb, &counter);
 
-	payload = arv_camera_get_payload (camera);
+	payload = arv_camera_get_payload (camera, NULL);
 	arv_stream_push_buffer (stream,  arv_buffer_new (payload, NULL));
-	arv_camera_set_acquisition_mode (camera, ARV_ACQUISITION_MODE_SINGLE_FRAME);
-	arv_camera_start_acquisition (camera);
+	arv_camera_set_acquisition_mode (camera, ARV_ACQUISITION_MODE_SINGLE_FRAME, NULL);
+	arv_camera_start_acquisition (camera, NULL);
 	buffer = arv_stream_pop_buffer (stream);
-	arv_camera_stop_acquisition (camera);
+	arv_camera_stop_acquisition (camera, NULL);
 
 	arv_fake_camera_set_fill_pattern (fake_camera, NULL, NULL);
 
@@ -316,10 +316,10 @@ fake_stream_test (void)
 static void
 camera_api_test (void)
 {
+	GError *error = NULL;
 	ArvCamera *camera;
 	ArvPixelFormat pixel_format;
-	ArvStatus status;
-	GError *error = NULL;
+	gboolean success;
 	int x, y, w, h;
 	const char *string;
 	void *ptr;
@@ -330,106 +330,137 @@ camera_api_test (void)
 	camera = arv_camera_new ("Fake_1");
 	g_assert (ARV_IS_CAMERA (camera));
 
-	string = arv_camera_get_vendor_name (camera);
+	string = arv_camera_get_vendor_name (camera, &error);
+	g_assert (error == NULL);
 	g_assert (string != NULL);
 
-	string = arv_camera_get_model_name (camera);
+	string = arv_camera_get_model_name (camera, &error);
+	g_assert (error == NULL);
 	g_assert (string != NULL);
 
-	string = arv_camera_get_device_id (camera);
+	string = arv_camera_get_device_id (camera, &error);
+	g_assert (error == NULL);
 	g_assert (string != NULL);
 
-	arv_camera_get_region (camera, &x, &y, &w, &h);
+	arv_camera_get_region (camera, &x, &y, &w, &h, &error);
+	g_assert (error == NULL);
 	g_assert_cmpint (x, ==, 0);
 	g_assert_cmpint (y, ==, 0);
 	g_assert_cmpint (w, ==, ARV_FAKE_CAMERA_WIDTH_DEFAULT);
 	g_assert_cmpint (h, ==, ARV_FAKE_CAMERA_HEIGHT_DEFAULT);
 
-	arv_camera_get_sensor_size (camera, &w, &h);
+	arv_camera_get_sensor_size (camera, &w, &h, &error);
+	g_assert (error == NULL);
 	g_assert_cmpint (w, ==, ARV_FAKE_CAMERA_SENSOR_WIDTH);
 	g_assert_cmpint (h, ==, ARV_FAKE_CAMERA_SENSOR_HEIGHT);
 
-	arv_camera_set_region (camera, 10, 20, 30, 40);
-	arv_camera_get_region (camera, &x, &y, &w, &h);
+	arv_camera_set_region (camera, 10, 20, 30, 40, &error);
+	g_assert (error == NULL);
+	arv_camera_get_region (camera, &x, &y, &w, &h, &error);
+	g_assert (error == NULL);
 	g_assert_cmpint (x, ==, 10);
 	g_assert_cmpint (y, ==, 20);
 	g_assert_cmpint (w, ==, 30);
 	g_assert_cmpint (h, ==, 40);
 
-	arv_camera_get_binning (camera, &x, &y);
+	arv_camera_get_binning (camera, &x, &y, &error);
+	g_assert (error == NULL);
 	g_assert_cmpint (x, ==, ARV_FAKE_CAMERA_BINNING_HORIZONTAL_DEFAULT);
 	g_assert_cmpint (y, ==, ARV_FAKE_CAMERA_BINNING_VERTICAL_DEFAULT);
 
-	arv_camera_set_binning (camera, 2, 4);
-	arv_camera_get_binning (camera, &x, &y);
+	arv_camera_set_binning (camera, 2, 4, &error);
+	g_assert (error == NULL);
+	arv_camera_get_binning (camera, &x, &y, &error);
+	g_assert (error == NULL);
 	g_assert_cmpint (x, ==, 2);
 	g_assert_cmpint (y, ==, 4);
 
-	b = arv_camera_is_binning_available (camera);
+	b = arv_camera_is_binning_available (camera, &error);
+	g_assert (error == NULL);
 	g_assert (b);
 
-	pixel_format = arv_camera_get_pixel_format (camera);
+	pixel_format = arv_camera_get_pixel_format (camera, &error);
+	g_assert (error == NULL);
 	g_assert_cmpint (pixel_format, ==, ARV_PIXEL_FORMAT_MONO_8);
 
-	arv_camera_set_pixel_format (camera, ARV_PIXEL_FORMAT_RGB_8_PACKED);
-	pixel_format = arv_camera_get_pixel_format (camera);
+	arv_camera_set_pixel_format (camera, ARV_PIXEL_FORMAT_RGB_8_PACKED, &error);
+	g_assert (error == NULL);
+	pixel_format = arv_camera_get_pixel_format (camera, &error);
+	g_assert (error == NULL);
 	g_assert_cmpint (pixel_format, ==, ARV_PIXEL_FORMAT_RGB_8_PACKED);
 
-	string = arv_camera_get_pixel_format_as_string (camera);
+	string = arv_camera_get_pixel_format_as_string (camera, &error);
+	g_assert (error == NULL);
 	g_assert_cmpstr (string, ==, "RGB8");
 
-	arv_camera_set_pixel_format_from_string (camera, "Mono8");
-	pixel_format = arv_camera_get_pixel_format (camera);
+	arv_camera_set_pixel_format_from_string (camera, "Mono8", &error);
+	g_assert (error == NULL);
+	pixel_format = arv_camera_get_pixel_format (camera, &error);
+	g_assert (error == NULL);
 	g_assert_cmpint (pixel_format, ==, ARV_PIXEL_FORMAT_MONO_8);
 
-	ptr = arv_camera_get_available_pixel_formats (camera, &n);
+	ptr = arv_camera_get_available_pixel_formats (camera, &n, &error);
+	g_assert (error == NULL);
 	g_assert (ptr != NULL);
 	g_assert_cmpint (n, ==, 2);
 	g_clear_pointer (&ptr, g_free);
 
-	ptr = arv_camera_get_available_pixel_formats_as_strings (camera, &n);
+	ptr = arv_camera_get_available_pixel_formats_as_strings (camera, &n, &error);
+	g_assert (error == NULL);
 	g_assert (ptr != NULL);
 	g_assert_cmpint (n, ==, 2);
 	g_clear_pointer (&ptr, g_free);
 
-	ptr = arv_camera_get_available_pixel_formats_as_display_names (camera, &n);
+	ptr = arv_camera_get_available_pixel_formats_as_display_names (camera, &n, &error);
+	g_assert (error == NULL);
 	g_assert (ptr != NULL);
 	g_assert_cmpint (n, ==, 2);
 	g_clear_pointer (&ptr, g_free);
 
-	b = arv_camera_is_frame_rate_available (camera);
+	b = arv_camera_is_frame_rate_available (camera, &error);
+	g_assert (error == NULL);
 	g_assert (b);
 
-	d = arv_camera_get_frame_rate (camera);
+	d = arv_camera_get_frame_rate (camera, &error);
+	g_assert (error == NULL);
 	g_assert_cmpfloat (d, ==, ARV_FAKE_CAMERA_ACQUISITION_FRAME_RATE_DEFAULT);
 
-	arv_camera_set_frame_rate (camera, 10.0);
-	d = arv_camera_get_frame_rate (camera);
+	arv_camera_set_frame_rate (camera, 10.0, &error);
+	g_assert (error == NULL);
+	d = arv_camera_get_frame_rate (camera, &error);
+	g_assert (error == NULL);
 	g_assert_cmpfloat (d, ==, 10.0);
 
-	b = arv_camera_is_exposure_auto_available (camera);
+	b = arv_camera_is_exposure_auto_available (camera, &error);
+	g_assert (error == NULL);
 	g_assert (!b);
 
-	b = arv_camera_is_exposure_time_available (camera);
+	b = arv_camera_is_exposure_time_available (camera, &error);
+	g_assert (error == NULL);
 	g_assert (b);
 
-	arv_camera_set_gain (camera, 1.0);
-	d = arv_camera_get_gain (camera);
+	arv_camera_set_gain (camera, 1.0, &error);
+	g_assert (error == NULL);
+	d = arv_camera_get_gain (camera, &error);
+	g_assert (error == NULL);
 	g_assert_cmpfloat (d, ==, 1.0);
 
-	status = arv_camera_get_status (camera, &error);
-	g_assert_cmpint (status, ==, ARV_STATUS_SUCCESS);
+	success = arv_camera_check_status (camera, &error);
+	g_assert (error == NULL);
+	g_assert (success);
 	g_assert (error == NULL);
 
-	arv_camera_set_integer (camera, "Unknown", 0);
-	status = arv_camera_get_status (camera, &error);
-	g_assert_cmpint (status, !=, ARV_STATUS_SUCCESS);
+	arv_camera_set_integer (camera, "Unknown", 0, &error);
+	g_assert (error != NULL);
+	g_clear_error (&error);
+	success = arv_camera_check_status (camera, &error);
+	g_assert (!success);
 	g_assert (error != NULL);
 	g_clear_error (&error);
 
 	/* Status is reset after read */
-	status = arv_camera_get_status (camera, &error);
-	g_assert_cmpint (status, ==, ARV_STATUS_SUCCESS);
+	success = arv_camera_check_status (camera, &error);
+	g_assert (success);
 	g_assert (error == NULL);
 
 	g_object_unref (camera);
